@@ -22,7 +22,7 @@ use OTRS::OPM::Maker -command;
 use OTRS::OPM::Maker::Utils::OTRS3;
 use OTRS::OPM::Maker::Utils::OTRS4;
 
-our $VERSION = 1.38;
+our $VERSION = 1.39;
 
 sub abstract {
     return "build sopm file based on metadata";
@@ -308,6 +308,14 @@ sub execute {
     }
     
     for my $code ( @{ $json->{code} || [] } ) {
+        if ( !ref $code ) {
+            $code = {
+                type    => $code,
+                version => 0,
+                phase   => ( $code eq 'Uninstall' ? 'pre' : 'post' ),
+            };
+        }
+
         $code->{type} = 'Code' . $code->{type};
         push @xml_parts, $utils->packagesetup(
             $code->{type},
@@ -648,7 +656,7 @@ OTRS::OPM::Maker::Command::sopm - Build .sopm file based on metadata
 
 =head1 VERSION
 
-version 1.38
+version 1.39
 
 =head1 DESCRIPTION
 
